summaryrefslogtreecommitdiff
path: root/src/include/taler_crypto_lib.h
diff options
context:
space:
mode:
authorFlorian Dold <florian.dold@gmail.com>2020-01-19 17:03:19 +0100
committerFlorian Dold <florian.dold@gmail.com>2020-01-19 17:03:19 +0100
commitfc8bdb9b978334d52b80c318f9326394f855de2d (patch)
tree428c6b9235dee248bef4fc7e7c41b029495b0d0f /src/include/taler_crypto_lib.h
parent9f522baadcf3b5288d35216962a91b5aeb688820 (diff)
downloadexchange-fc8bdb9b978334d52b80c318f9326394f855de2d.tar.gz
exchange-fc8bdb9b978334d52b80c318f9326394f855de2d.tar.bz2
exchange-fc8bdb9b978334d52b80c318f9326394f855de2d.zip
consistently use payto URI instead of URL
Diffstat (limited to 'src/include/taler_crypto_lib.h')
-rw-r--r--src/include/taler_crypto_lib.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/include/taler_crypto_lib.h b/src/include/taler_crypto_lib.h
index 2a4b0ca8f..3fd727235 100644
--- a/src/include/taler_crypto_lib.h
+++ b/src/include/taler_crypto_lib.h
@@ -741,24 +741,24 @@ TALER_refresh_get_commitment (struct TALER_RefreshCommitmentP *rc,
* Compute the hash of the given wire details. The resulting
* hash is what is put into the contract.
*
- * @param payto_url bank account
+ * @param payto_uri bank account
* @param[out] hc set to the hash
*/
void
-TALER_exchange_wire_signature_hash (const char *payto_url,
+TALER_exchange_wire_signature_hash (const char *payto_uri,
struct GNUNET_HashCode *hc);
/**
* Check the signature in @a wire_s.
*
* @param payto_url URL that is signed
* @param master_pub master public key of the exchange
* @param master_sig signature of the exchange
* @return #GNUNET_OK if signature is valid
*/
int
-TALER_exchange_wire_signature_check (const char *payto_url,
+TALER_exchange_wire_signature_check (const char *payto_uri,
const struct
TALER_MasterPublicKeyP *master_pub,
const struct
@@ -768,12 +768,12 @@ TALER_exchange_wire_signature_check (const char *payto_url,
/**
* Create a signed wire statement for the given account.
*
- * @param payto_url account specification
+ * @param payto_uri account specification
* @param master_priv private key to sign with
* @param[out] master_sig where to write the signature
*/
void
-TALER_exchange_wire_signature_make (const char *payto_url,
+TALER_exchange_wire_signature_make (const char *payto_uri,
const struct
TALER_MasterPrivateKeyP *master_priv,
struct TALER_MasterSignatureP *master_sig);
@@ -783,12 +783,12 @@ TALER_exchange_wire_signature_make (const char *payto_url,
* Compute the hash of the given wire details. The resulting
* hash is what is put into the contract.
*
- * @param payto_url bank account
+ * @param payto_uri bank account
* @param salt salt used to eliminate brute-force inversion
* @param[out] hc set to the hash
*/
void
-TALER_merchant_wire_signature_hash (const char *payto_url,
+TALER_merchant_wire_signature_hash (const char *payto_uri,
const char *salt,
struct GNUNET_HashCode *hc);
@@ -796,14 +796,14 @@ TALER_merchant_wire_signature_hash (const char *payto_url,
/**
* Check the signature in @a wire_s.
*
* @param payto_url URL that is signed
* @param salt the salt used to salt the @a payto_url when hashing
* @param merch_pub public key of the merchant
* @param merch_sig signature of the merchant
* @return #GNUNET_OK if signature is valid
*/
int
-TALER_merchant_wire_signature_check (const char *payto_url,
+TALER_merchant_wire_signature_check (const char *payto_uri,
const char *salt,
const struct
TALER_MerchantPublicKeyP *merch_pub,
@@ -814,13 +814,13 @@ TALER_merchant_wire_signature_check (const char *payto_url,
/**
* Create a signed wire statement for the given account.
*
* @param payto_url account specification
* @param salt the salt used to salt the @a payto_url when hashing
* @param merch_priv private key to sign with
* @param[out] merch_sig where to write the signature
*/
void
-TALER_merchant_wire_signature_make (const char *payto_url,
+TALER_merchant_wire_signature_make (const char *payto_uri,
const char *salt,
const struct
TALER_MerchantPrivateKeyP *merch_priv,
@@ -741,24 +741,24 @@ TALER_refresh_get_commitment (struct TALER_RefreshCommitmentP *rc,
* Check the signature in @a wire_s.
*
- * @param payto_url URL that is signed
+ * @param payto_uri URL that is signed
* @param master_pub master public key of the exchange
* @param master_sig signature of the exchange
@@ -796,14 +796,14 @@ TALER_merchant_wire_signature_hash (const char *payto_url,
* Check the signature in @a wire_s.
*
- * @param payto_url URL that is signed
- * @param salt the salt used to salt the @a payto_url when hashing
+ * @param payto_uri URL that is signed
+ * @param salt the salt used to salt the @a payto_uri when hashing
* @param merch_pub public key of the merchant
* @param merch_sig signature of the merchant
@@ -814,13 +814,13 @@ TALER_merchant_wire_signature_check (const char *payto_url,
* Create a signed wire statement for the given account.
*
- * @param payto_url account specification
- * @param salt the salt used to salt the @a payto_url when hashing
+ * @param payto_uri account specification
+ * @param salt the salt used to salt the @a payto_uri when hashing
* @param merch_priv private key to sign with
* @param[out] merch_sig where to write the signature